@@ -4,11 +4,11 @@ from typing import List
 import requests
 
 from maitai._config_listener_thread import ConfigListenerThread
+from maitai._utils import __version__ as version
 from maitai_common.config import config_service
-from maitai_common.version import version
 from maitai_gen.application import Application
-from maitai_gen.chat import ChatCompletionAuth
 from maitai_gen.config import Config as ActionConfig
+from maitai_gen.key import Key, KeyMap
 
 
 class Config:
@@ -23,9 +23,10 @@ class Config:
         self.config_listener_thread = None
         self._application_action_configs: dict[str, dict[str, ActionConfig]] = {}
         self.initialized = False
-        self.auth_info = ChatCompletionAuth(
-            openai_api_key=os.environ.get("OPENAI_API_KEY"),
-            groq_api_key=os.environ.get("GROQ_API_KEY"),
+        self.auth_keys: KeyMap = KeyMap(
+            openai_api_key=Key(id=-1, key_value=os.environ.get("OPENAI_API_KEY")),
+            groq_api_key=Key(id=-1, key_value=os.environ.get("GROQ_API_KEY")),
+            anthropic_api_key=Key(id=-1, key_value=os.environ.get("ANTHROPIC_API_KEY")),
         )
 
     @property
@@ -66,7 +67,7 @@ class Config:
             'x-client-version': version,
         }
 
-        response = requests.get(url, headers=headers)
+        response = requests.get(url, headers=headers, timeout=10)
         if response.status_code != 200:
             print(f"Failed to initialize API client. Status code: {response.status_code}. Error: {response.text}")
             return
@@ -82,7 +83,7 @@ class Config:
             'x-client-version': version,
         }
 
-        response = requests.get(url, headers=headers)
+        response = requests.get(url, headers=headers, timeout=10)
         if response.status_code != 200:
             print(f"Failed to initialize API client. Status code: {response.status_code}. Error: {response.text}")
             return
