@@ -7,9 +7,8 @@ from betterproto import Casing
 
 from maitai._config import config
 from maitai._maitai_client import MaitaiClient
-from maitai._utils import chat_completion_chunk_to_response
+from maitai._utils import __version__ as version, chat_completion_chunk_to_response
 from maitai_common.utils.types import AsyncChunkQueue, ChunkQueue, EvaluateCallback, QueueIterable
-from maitai_common.version import version
 from maitai_gen.chat import ChatCompletionChunk, ChatCompletionParams, ChatCompletionRequest, ChatCompletionResponse, ChatStorageRequest
 from maitai_gen.inference import InferenceStreamResponse
 
@@ -31,8 +30,9 @@ class Inference(MaitaiClient):
 
     @classmethod
     def infer(cls, session_id, reference_id, intent, application_ref_name, completion_params: ChatCompletionParams, apply_corrections: bool, evaluation_enabled: bool, evaluate_callback: EvaluateCallback = None,
-              timeout=None, context_retrieval_enabled=False, context_query='') -> Iterable[InferenceStreamResponse]:
-        chat_request: ChatCompletionRequest = cls.create_inference_request(application_ref_name, session_id, reference_id, intent, apply_corrections, evaluation_enabled, completion_params, evaluate_callback, context_retrieval_enabled, context_query)
+              timeout=None, context_retrieval_enabled=False, context_query='', return_request=False, fallback_model=None) -> Iterable[InferenceStreamResponse]:
+        chat_request: ChatCompletionRequest = cls.create_inference_request(application_ref_name, session_id, reference_id, intent, apply_corrections, evaluation_enabled, completion_params, evaluate_callback,
+                                                                           context_retrieval_enabled, context_query, return_request, fallback_model)
         if evaluate_callback:
             q = ChunkQueue()
             cls.run_async(cls.send_inference_request_async(chat_request, chunk_queue=q, evaluation_callback=evaluate_callback))
@@ -42,8 +42,9 @@ class Inference(MaitaiClient):
 
     @classmethod
     async def infer_async(cls, session_id, reference_id, intent, application_ref_name, completion_params: ChatCompletionParams, apply_corrections: bool, evaluation_enabled: bool,
-                          evaluate_callback: EvaluateCallback = None, timeout=None, context_retrieval_enabled=False, context_query='') -> AsyncIterable[InferenceStreamResponse]:
-        chat_request: ChatCompletionRequest = cls.create_inference_request(application_ref_name, session_id, reference_id, intent, apply_corrections, evaluation_enabled, completion_params, evaluate_callback, context_retrieval_enabled, context_query)
+                          evaluate_callback: EvaluateCallback = None, timeout=None, context_retrieval_enabled=False, context_query='', fallback_model=None) -> AsyncIterable[InferenceStreamResponse]:
+        chat_request: ChatCompletionRequest = cls.create_inference_request(application_ref_name, session_id, reference_id, intent, apply_corrections, evaluation_enabled, completion_params, evaluate_callback,
+                                                                           context_retrieval_enabled, context_query, fallback_model)
         q = AsyncChunkQueue()
         cls.run_async(cls.send_inference_request_async(chat_request, async_chunk_queue=q, evaluation_callback=evaluate_callback))
         return QueueIterable(q, timeout=timeout)
