@@ -1,3 +1,4 @@
+import os
 import warnings
 from typing import Dict, Iterable, List, Mapping, Optional, Union
 
@@ -30,6 +31,7 @@ class Maitai:
         api_key: Optional[str] = None,
         openai_api_key: Optional[str] = None,
         groq_api_key: Optional[str] = None,
+        anthropic_api_key: Optional[str] = None,
         organization: Optional[str] = None,
         project: Optional[str] = None,
         base_url: Union[str, httpx.URL, None] = None,
@@ -40,26 +42,35 @@ class Maitai:
         http_client: Optional[httpx.Client] = None,
         _strict_response_validation: bool = False,
     ):
-        if api_key:
-            print("Warning: The api_key parameter is not supported by Maitai. Provide openai_api_key or groq_api_key instead")
         if maitai_api_key:
             config.initialize(maitai_api_key)
+        if api_key:
+            if not openai_api_key:
+                openai_api_key = api_key
+            if not groq_api_key:
+                groq_api_key = api_key
+            if not anthropic_api_key:
+                anthropic_api_key = api_key
         if openai_api_key:
             config.auth_keys.openai_api_key.key_value = openai_api_key
         if groq_api_key:
             config.auth_keys.groq_api_key.key_value = groq_api_key
-        self.client = openai.OpenAI(
-            api_key=api_key or openai_api_key,
-            organization=organization,
-            project=project,
-            base_url=base_url,
-            timeout=timeout,
-            max_retries=max_retries,
-            default_headers=default_headers,
-            default_query=default_query,
-            http_client=http_client,
-            _strict_response_validation=_strict_response_validation,
-        )
+        if anthropic_api_key:
+            config.auth_keys.anthropic_api_key.key_value = anthropic_api_key
+        self.client = None
+        if api_key or openai_api_key or os.environ.get("OPENAI_API_KEY"):
+            self.client = openai.OpenAI(
+                api_key=api_key or openai_api_key or os.environ.get("OPENAI_API_KEY"),
+                organization=organization,
+                project=project,
+                base_url=base_url,
+                timeout=timeout,
+                max_retries=max_retries,
+                default_headers=default_headers,
+                default_query=default_query,
+                http_client=http_client,
+                _strict_response_validation=_strict_response_validation,
+            )
         self.chat = Chat(self.client)
 
 
@@ -93,6 +104,8 @@ class Completions:
         apply_corrections: bool = None,
         context_retrieval_enabled: bool = None,
         context_query: str = '',
+        return_request: bool = False,
+        fallback_model: str = None,
         # OpenAI Arguments
         messages: Iterable[openai_chat_types.ChatCompletionMessageParam],
         model: Union[str, openai_types.ChatModel, openai.NotGiven] = openai.NOT_GIVEN,
@@ -187,7 +200,7 @@ class Completions:
             if isinstance(timeout, float) or isinstance(timeout, int):
                 response_timeout = timeout
             response = maitai.Inference.infer(session_id, reference_id, intent, application_ref_name, completion_params, apply_corrections, evaluation_enabled, callback, timeout=response_timeout,
-                                              context_retrieval_enabled=context_retrieval_enabled, context_query=context_query)
+                                              context_retrieval_enabled=context_retrieval_enabled, context_query=context_query, return_request=return_request, fallback_model=fallback_model)
             if stream:
                 return _process_inference_stream(response)
             # ChatCompletion only
