@@ -30,6 +30,7 @@ class MaitaiAsync:
         api_key: Optional[str] = None,
         openai_api_key: Optional[str] = None,
         groq_api_key: Optional[str] = None,
+        anthropic_api_key: Optional[str] = None,
         organization: Optional[str] = None,
         project: Optional[str] = None,
         base_url: Union[str, httpx.URL, None] = None,
@@ -41,14 +42,21 @@ class MaitaiAsync:
         _strict_response_validation: bool = False,
 
     ):
-        if api_key:
-            print("Warning: The api_key parameter is not supported by Maitai. Provide openai_api_key or groq_api_key instead")
         if maitai_api_key:
             config.initialize(maitai_api_key)
+        if api_key:
+            if not openai_api_key:
+                openai_api_key = api_key
+            if not groq_api_key:
+                groq_api_key = api_key
+            if not anthropic_api_key:
+                anthropic_api_key = api_key
         if openai_api_key:
             config.auth_keys.openai_api_key.key_value = openai_api_key
         if groq_api_key:
             config.auth_keys.groq_api_key.key_value = groq_api_key
+        if anthropic_api_key:
+            config.auth_keys.anthropic_api_key.key_value = anthropic_api_key
         self.client = openai.AsyncClient(
             api_key=api_key or openai_api_key,
             organization=organization,
@@ -97,6 +105,7 @@ class AsyncCompletions:
         apply_corrections: bool = None,
         context_retrieval_enabled: bool = None,
         context_query: str = None,
+        fallback_model: str = None,
         # OpenAI Arguments
         messages: Iterable[openai_chat_types.ChatCompletionMessageParam],
         model: Union[str, openai_types.ChatModel, openai.NotGiven] = openai.NOT_GIVEN,
@@ -192,7 +201,7 @@ class AsyncCompletions:
             if isinstance(timeout, float) or isinstance(timeout, int):
                 response_timeout = timeout
             response = await maitai.Inference.infer_async(session_id, reference_id, intent, application_ref_name, completion_params, apply_corrections, evaluation_enabled, callback, timeout=response_timeout,
-                                                          context_retrieval_enabled=context_retrieval_enabled, context_query=context_query)
+                                                          context_retrieval_enabled=context_retrieval_enabled, context_query=context_query, fallback_model=fallback_model)
             if stream:
                 return _process_inference_stream_async(response)
             # ChatCompletion only
